==> 0.0.24.tar.gz: west-sound-hall/src/app/calendar/calendar.tsx <==
'use client'

import {
    ChevronLeftIcon,
    ChevronRightIcon,
    ClockIcon,
} from '@heroicons/react/20/solid'

import dayjs from "dayjs";
import React from 'react';
import { Calendar, Event } from './page';
import Link from 'next/link';

interface day {
    date: dayjs.Dayjs;
    isCurrentMonth: boolean;
    isToday: boolean;
}


function classNames(...classes: string[]): string {
    return classes.filter(Boolean).join(' ');
}

const getEvents = (cal: Calendar, d: dayjs.Dayjs): Event[] => {
    const year = cal[d.year()];
    if (!year) {
        return [];
    }

    const month = year[d.month()];
    if (!month) {
        return [];
    }

    return month[d.date()] || [];
}

export const CalendarComponent: React.FC<{ calendar: Calendar }> = ({ calendar }) => {
    const [selectedDay, setSelectedDay] = React.useState(dayjs().startOf('day'));
    const [selectedMonth, setSelectedMonth] = React.useState(dayjs().startOf('month'));

    const days = React.useMemo(() => {
        // Number of greyed days shown before the beginning of the current month.
        const renderedDaysBeforeMonth = selectedMonth.day();
        const firstDay = selectedMonth.subtract(renderedDaysBeforeMonth, 'day');
        const month = selectedMonth.month();
        const today = dayjs().startOf('day');

        let current = firstDay;
        const days: day[] = [];

        // Fill out the first week with days from the previous month.
        for (let i = 0; i < renderedDaysBeforeMonth; i++) {
            days.push({
                date: current,
                isCurrentMonth: false,
                isToday: current.isSame(today),
            });
            current = current.add(1, 'day');
        }

        // Add the days for the selected month.
        while (current.month() === month) {
            days.push({
                date: current,
                isCurrentMonth: true,
                isToday: current.isSame(today),
            });
            current = current.add(1, 'day');
        }

        // Finish out the week with days from the following month.
        while (current.day() > 0) {
            days.push({
                date: current,
                isCurrentMonth: false,
                isToday: current.isSame(today),
            });
            current = current.add(1, 'day');
        }

        return days;
    }, [selectedMonth]);

    const isSelectedDay = (d: day): boolean => {
        return d.date.isSame(selectedDay);
    }

    const selectedDayEvents = React.useMemo(() => {
        return getEvents(calendar, selectedDay);
    }, [calendar, selectedDay]);

    return (
        <div className="lg:flex lg:h-full lg:flex-col">
            <header className="flex items-center justify-between border-b border-zinc-100 py-4 lg:flex-none">
                <h1 className="text-base font-semibold leading-6 text-zinc-800">
                    <time dateTime={selectedMonth.format('YYYY-MM')}>{selectedMonth.format('MMMM YYYY')}</time>
                </h1>
                <div className="flex items-center">
                    <div className="relative flex items-center rounded-md shadow-sm md:items-stretch">
                        <button
                            type="button"
                            onClick={() => { setSelectedMonth(selectedMonth.subtract(1, 'month')) }}
                            className="flex h-9 w-12 items-center justify-center rounded-l-md border-y border-l border-zinc-100 pr-1 text-gray-400 hover:text-gray-500 focus:relative md:w-9 md:pr-0 md:hover:bg-gray-50"
                        >
                            <span className="sr-only">Previous month</span>
                            <ChevronLeftIcon className="h-5 w-5" aria-hidden="true" />
                        </button>
                        <button
                            type="button"
                            onClick={() => {
                                setSelectedDay(dayjs().startOf('day'))
                                setSelectedMonth(dayjs().startOf('month'));
                            }}
                            className="hidden border-y border-zinc-100 px-3.5 text-sm font-semibold text-zinc-800 hover:bg-gray-50 focus:relative md:block"
                        >
                            Today
                        </button>
                        <span className="relative -mx-px h-5 w-px bg-gray-300 md:hidden" />
                        <button
                            type="button"
                            onClick={() => { setSelectedMonth(selectedMonth.add(1, 'month')) }}
                            className="flex h-9 w-12 items-center justify-center rounded-r-md border-y border-r border-zinc-100 pl-1 text-gray-400 hover:text-gray-500 focus:relative md:w-9 md:pl-0 md:hover:bg-gray-50"
                        >
                            <span className="sr-only">Next month</span>
                            <ChevronRightIcon className="h-5 w-5" aria-hidden="true" />
                        </button>
                    </div>
                </div>
            </header>
            <div className="shadow ring-1 ring-black ring-opacity-5 lg:flex lg:flex-auto lg:flex-col">
                <div className="grid grid-cols-7 gap-px border-b border-zinc-100 bg-gray-200 text-center text-xs font-semibold leading-6 text-gray-700 lg:flex-none">
                    {[['M', 'on'], ['T', 'ue'], ['W', 'ed'], ['T', 'hu'], ['F', 'ri'], ['S', 'at'], ['S', 'un']].map((d) => (
                        <div key={d[0] + d[1]} className="bg-white py-2">
                            {d[0]}<span className="sr-only sm:not-sr-only">{d[1]}</span>
                        </div>
                    ))}
                </div>
                <div className="flex bg-gray-200 text-xs leading-6 text-gray-700 lg:flex-auto">
                    <div className="isolate grid w-full grid-cols-7 gap-px">
                        {days.map((day) => {
                            const events = getEvents(calendar, day.date);
                            const isSelected = isSelectedDay(day);

                            return (
                                <button
                                    key={day.date.format('YYYY-MM-DD')}
                                    type="button"
                                    onClick={() => { setSelectedDay(day.date) }}
                                    className={classNames(
                                        day.isCurrentMonth ? 'bg-white' : 'bg-gray-50',
                                        isSelected || day.isToday ? 'font-semibold' : '',
                                        isSelected ? 'text-white' : '',
                                        !isSelected && day.isToday ? 'text-indigo-600' : '',
                                        !isSelected && day.isCurrentMonth && !day.isToday ? 'text-gray-900' : '',
                                        !isSelected && !day.isCurrentMonth && !day.isToday ? 'text-gray-500' : '',
                                        'flex h-12 sm:h-14 md:h-16 lg:h-24 flex-col px-3 py-2 hover:bg-gray-100 focus:z-10'
                                    )}
                                >
                                    <time
                                        dateTime={day.date.format('YYYY-MM-DD')}
                                        className={classNames(
                                            isSelected ? 'flex h-6 w-6 items-center justify-center rounded-full' : '',
                                            isSelected && day.isToday ? 'bg-indigo-600' : '',
                                            isSelected && !day.isToday ? 'bg-gray-900' : '',
                                            'ml-auto'
                                        )}
                                    >
                                        {day.date.date()}
                                    </time>
                                    <span className="sr-only">{events.length} events</span>
                                    {events.length > 0 && (
                                        <>
                                            <span className="-mx-0.5 mt-auto flex flex-wrap-reverse lg:hidden">
                                                {events.map((event) => (
                                                    <span key={event.id} className="mx-0.5 mb-1 h-1.5 w-1.5 rounded-full bg-gray-400" />
                                                ))}
                                            </span>
                                            <ol className="mt-2 hidden lg:block">
                                                {events.slice(0, 2).map((event) => (
                                                    <li key={event.id}>
                                                        <p className="flex-auto truncate font-medium text-gray-900 group-hover:text-indigo-600">
                                                            {event.name}
                                                        </p>
                                                    </li>
                                                ))}
                                                {events.length > 2 && <li className="text-gray-500">+ {events.length - 2} more</li>}
                                            </ol>
                                        </>
                                    )}
                                </button>
                            );
                        })}
                    </div>
                </div>
            </div>
            <div className="pt-10">
                <h2 className="text-base font-semibold leading-6 text-zinc-800">
                    Events on <time dateTime={selectedDay.format('YYYY-MM-DD')}>{selectedDay.format('MMMM D')}</time>
                </h2>
                {selectedDayEvents.length > 0 && (
                    <div className="py-5">
                        <ol className="divide-y divide-gray-100 overflow-hidden rounded-lg bg-white text-sm shadow ring-1 ring-black ring-opacity-5">
                            {selectedDayEvents.map((event) => {
                                const start = dayjs(event.start);
                                return (
                                    <li key={event.id} className="group flex p-4 pr-6 focus-within:bg-gray-50 hover:bg-gray-50">
                                        <div className="flex-auto">
                                            <p className="font-semibold text-gray-900">{event.name}</p>
                                            <time dateTime={start.format('YYYY-MM-DD HH:mm')} className="mt-2 flex items-center text-gray-700">
                                                <ClockIcon className="mr-2 h-5 w-5 text-gray-400" aria-hidden="true" />
                                                {event.allDay
                                                    ? "All day"
                                                    : start.format("h:mm a")
                                                }
                                            </time>
                                        </div>
                                    </li>
                                );
                            })}
                        </ol>
                    </div>
                )}
                {selectedDayEvents.length === 0 && (
                    <p className="py-6 text-sm font-semibold text-gray-600">No events on this day</p>
                )}
            </div>
            <div>
                <p>
                    If you are interested in reserving the hall, please see the
                    <Link href="/rental" className="pl-1 text-blue-600 hover:underline"
                    >hall rental page
                    </Link>.
                </p>
            </div>
        </div>
    )
}

==> 0.0.29.tar.gz: west-sound-hall/src/app/calendar/calendar.tsx <==
'use client'

import {
    ChevronLeftIcon,
    ChevronRightIcon,
    ClockIcon,
} from '@heroicons/react/20/solid'

import dayjs from "dayjs";
import React from 'react';
import { Calendar, Event } from './page';
import Link from 'next/link';

interface day {
    date: dayjs.Dayjs;
    isCurrentMonth: boolean;
    isToday: boolean;
}


function classNames(...classes: string[]): string {
    return classes.filter(Boolean).join(' ');
}

const getEvents = (cal: Calendar, d: dayjs.Dayjs): Event[] => {
    const year = cal[d.year()];
    if (!year) {
        return [];
    }

    const month = year[d.month()];
    if (!month) {
        return [];
    }

    return month[d.date()] || [];
}

export const CalendarComponent: React.FC<{ calendar: Calendar }> = ({ calendar }) => {
    const [selectedDay, setSelectedDay] = React.useState(dayjs().startOf('day'));
    const [selectedMonth, setSelectedMonth] = React.useState(dayjs().startOf('month'));

    const days = React.useMemo(() => {
        // Number of greyed days shown before the beginning of the current month.
        const renderedDaysBeforeMonth = selectedMonth.day();
        const firstDay = selectedMonth.subtract(renderedDaysBeforeMonth, 'day');
        const month = selectedMonth.month();
        const today = dayjs().startOf('day');

        let current = firstDay;
        const days: day[] = [];

        // Fill out the first week with days from the previous month.
        for (let i = 0; i < renderedDaysBeforeMonth; i++) {
            days.push({
                date: current,
                isCurrentMonth: false,
                isToday: current.isSame(today),
            });
            current = current.add(1, 'day');
        }

        // Add the days for the selected month.
        while (current.month() === month) {
            days.push({
                date: current,
                isCurrentMonth: true,
                isToday: current.isSame(today),
            });
            current = current.add(1, 'day');
        }

        // Finish out the week with days from the following month.
        while (current.day() > 0) {
            days.push({
                date: current,
                isCurrentMonth: false,
                isToday: current.isSame(today),
            });
            current = current.add(1, 'day');
        }

        return days;
    }, [selectedMonth]);

    const isSelectedDay = (d: day): boolean => {
        return d.date.isSame(selectedDay);
    }

    const selectedDayEvents = React.useMemo(() => {
        return getEvents(calendar, selectedDay);
    }, [calendar, selectedDay]);

    return (
        <div className="lg:flex lg:h-full lg:flex-col">
            <header className="flex items-center justify-between border-b border-zinc-100 py-4 lg:flex-none">
                <h1 className="text-base font-semibold leading-6 text-zinc-800">
                    <time dateTime={selectedMonth.format('YYYY-MM')}>{selectedMonth.format('MMMM YYYY')}</time>
                </h1>
                <div className="flex items-center">
                    <div className="relative flex items-center rounded-md shadow-sm md:items-stretch">
                        <button
                            type="button"
                            onClick={() => { setSelectedMonth(selectedMonth.subtract(1, 'month')) }}
                            className="flex h-9 w-12 items-center justify-center rounded-l-md border-y border-l border-zinc-100 pr-1 text-gray-400 hover:text-gray-500 focus:relative md:w-9 md:pr-0 md:hover:bg-gray-50"
                        >
                            <span className="sr-only">Previous month</span>
                            <ChevronLeftIcon className="h-5 w-5" aria-hidden="true" />
                        </button>
                        <button
                            type="button"
                            onClick={() => {
                                setSelectedDay(dayjs().startOf('day'))
                                setSelectedMonth(dayjs().startOf('month'));
                            }}
                            className="hidden border-y border-zinc-100 px-3.5 text-sm font-semibold text-zinc-800 hover:bg-gray-50 focus:relative md:block"
                        >
                            Today
                        </button>
                        <span className="relative -mx-px h-5 w-px bg-gray-300 md:hidden" />
                        <button
                            type="button"
                            onClick={() => { setSelectedMonth(selectedMonth.add(1, 'month')) }}
                            className="flex h-9 w-12 items-center justify-center rounded-r-md border-y border-r border-zinc-100 pl-1 text-gray-400 hover:text-gray-500 focus:relative md:w-9 md:pl-0 md:hover:bg-gray-50"
                        >
                            <span className="sr-only">Next month</span>
                            <ChevronRightIcon className="h-5 w-5" aria-hidden="true" />
                        </button>
                    </div>
                </div>
            </header>
            <div className="shadow ring-1 ring-black ring-opacity-5 lg:flex lg:flex-auto lg:flex-col">
                <div className="grid grid-cols-7 gap-px border-b border-zinc-100 bg-gray-200 text-center text-xs font-semibold leading-6 text-gray-700 lg:flex-none">
                    {[['S', 'un'], ['M', 'on'], ['T', 'ue'], ['W', 'ed'], ['T', 'hu'], ['F', 'ri'], ['S', 'at']].map((d) => (
                        <div key={d[0] + d[1]} className="bg-white py-2">
                            {d[0]}<span className="sr-only sm:not-sr-only">{d[1]}</span>
                        </div>
                    ))}
                </div>
                <div className="flex bg-gray-200 text-xs leading-6 text-gray-700 lg:flex-auto">
                    <div className="isolate grid w-full grid-cols-7 gap-px">
                        {days.map((day) => {
                            const events = getEvents(calendar, day.date);
                            const isSelected = isSelectedDay(day);

                            return (
                                <button
                                    key={day.date.format('YYYY-MM-DD')}
                                    type="button"
                                    onClick={() => { setSelectedDay(day.date) }}
                                    className={classNames(
                                        day.isCurrentMonth ? 'bg-white' : 'bg-gray-50',
                                        isSelected || day.isToday ? 'font-semibold' : '',
                                        isSelected ? 'text-white' : '',
                                        !isSelected && day.isToday ? 'text-indigo-600' : '',
                                        !isSelected && day.isCurrentMonth && !day.isToday ? 'text-gray-900' : '',
                                        !isSelected && !day.isCurrentMonth && !day.isToday ? 'text-gray-500' : '',
                                        'flex h-12 sm:h-14 md:h-16 lg:h-24 flex-col px-3 py-2 hover:bg-gray-100 focus:z-10'
                                    )}
                                >
                                    <time
                                        dateTime={day.date.format('YYYY-MM-DD')}
                                        className={classNames(
                                            isSelected ? 'flex h-6 w-6 items-center justify-center rounded-full' : '',
                                            isSelected && day.isToday ? 'bg-indigo-600' : '',
                                            isSelected && !day.isToday ? 'bg-gray-900' : '',
                                            'ml-auto'
                                        )}
                                    >
                                        {day.date.date()}
                                    </time>
                                    <span className="sr-only">{events.length} events</span>
                                    {events.length > 0 && (
                                        <>
                                            <span className="-mx-0.5 mt-auto flex flex-wrap-reverse lg:hidden">
                                                {events.map((event) => (
                                                    <span key={event.id} className="mx-0.5 mb-1 h-1.5 w-1.5 rounded-full bg-gray-400" />
                                                ))}
                                            </span>
                                            <ol className="mt-2 hidden lg:block">
                                                {events.slice(0, 2).map((event) => (
                                                    <li key={event.id}>
                                                        <p className="flex-auto truncate font-medium text-gray-900 group-hover:text-indigo-600">
                                                            {event.name}
                                                        </p>
                                                    </li>
                                                ))}
                                                {events.length > 2 && <li className="text-gray-500">+ {events.length - 2} more</li>}
                                            </ol>
                                        </>
                                    )}
                                </button>
                            );
                        })}
                    </div>
                </div>
            </div>
            <div className="pt-10">
                <h2 className="text-base font-semibold leading-6 text-zinc-800">
                    Events on <time dateTime={selectedDay.format('YYYY-MM-DD')}>{selectedDay.format('MMMM D')}</time>
                </h2>
                {selectedDayEvents.length > 0 && (
                    <div className="py-5">
                        <ol className="divide-y divide-gray-100 overflow-hidden rounded-lg bg-white text-sm shadow ring-1 ring-black ring-opacity-5">
                            {selectedDayEvents.map((event) => {
                                const start = dayjs(event.start);
                                return (
                                    <li key={event.id} className="group flex p-4 pr-6 focus-within:bg-gray-50 hover:bg-gray-50">
                                        <div className="flex-auto">
                                            <p className="font-semibold text-gray-900">{event.name}</p>
                                            <time dateTime={start.format('YYYY-MM-DD HH:mm')} className="mt-2 flex items-center text-gray-700">
                                                <ClockIcon className="mr-2 h-5 w-5 text-gray-400" aria-hidden="true" />
                                                {event.allDay
                                                    ? "All day"
                                                    : start.format("h:mm a")
                                                }
                                            </time>
                                        </div>
                                    </li>
                                );
                            })}
                        </ol>
                    </div>
                )}
                {selectedDayEvents.length === 0 && (
                    <p className="py-6 text-sm font-semibold text-gray-600">No events on this day</p>
                )}
            </div>
            <div>
                <p>
                    If you are interested in reserving the hall, please see the
                    <Link href="/rental" className="pl-1 text-blue-600 hover:underline"
                    >hall rental page
                    </Link>.
                </p>
            </div>
        </div>
    )
}
